/* extension.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 * 
 * Based on https://github.com/orschiro/adjust-brightness-icon
 * 
 */

const St = imports.gi.St; //Gobject-Introspection https://developer.gnome.org/gobject/stable/
const Main = imports.ui.main; //Main.layoutManager.monitor https://developer.gnome.org/gtk3/stable/
const Clutter = imports.gi.Clutter;

// The dimming is achieved by inserting a label with null text object and with an alpha channel that
// covers the whole screen. The text, being null, is not display, but the alpha channel remains; thus, achieving dimming. 
var label, button;
var currentOpacity = 0;

// reset opacity to 0 and remove label 
function reset() {
    currentOpacity = 0;
    Main.uiGroup.remove_actor(label); // remove label because sometimes screenshots stay dark even at 0 opacity
    label = null;
}

// Set opacity to 80 on click. Reset it on second click.
function handleIconClick() {
    if (currentOpacity != 80) {
        // increase opacity
        currentOpacity = 80;
        // update in monitor
        update();
    } else {
	reset();
    }
}

// toggle new brightness level
function update() {
    let monitor = Main.layoutManager.primaryMonitor;
    // let monitor2 = Main.layoutManager.secondaryMonitor;
    let myText = null;
    // myText = "hi 2: " + monitor2.x;

    if (label == null) {
        label = new St.Label({
                        style_class: 'helloworld-label', // add CSS label
                        text: myText
                        });
        Main.uiGroup.add_actor(label);
    }

    // set label opacity
    label.opacity = currentOpacity;
    // position label at 0,0 and stretch across the entire monitor
    label.set_position(0, 0); //override
    label.set_width(monitor.width * 6); //simply give enough width
    label.set_height(monitor.height * 6);
}

function init() {
}

function enable() {
    button = new St.Bin({ style_class: 'panel-button', 
                          reactive: true,
                          can_focus: true,
                          track_hover: true });

    // brightness icon
    let icon = new St.Icon({ icon_name: 'display-brightness-symbolic',
                             style_class: 'panelItem',
                             y_align: Clutter.ActorAlign.FILL });

    button.set_child(icon);

    button.connect('button-press-event', handleIconClick);
  
    Main.panel._rightBox.insert_child_at_index(button, 0);
}

function disable() {
    Main.panel._rightBox.remove_child(button);  
    button.destroy();
}
